==> haskell-libxml-0.1.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libxml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libxml
version: 0.1.1
id: libxml-0.1.1-DASs7VNHhWqCsnCWtz5QqF
key: libxml-0.1.1-DASs7VNHhWqCsnCWtz5QqF
license: BSD3
copyright: 2006, Lemmih
maintainer: Lemmih (lemmih@gmail.com)
synopsis: Binding to libxml2
description:
    Minimal binding to libxml2. Additional functions will be added when needed.
category: XML
author: Lemmih (lemmih@gmail.com)
exposed: True
indefinite: False
exposed-modules:
    Text.XML.LibXML Text.XML.LibXML.Internals Text.XML.LibXML.Parser
    Text.XML.LibXML.Tree Text.XML.LibXML.Types
abi: be7ec2382ddc6530de593c78fc2c2b02
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/libxml-0.1.1
hs-libraries: HSlibxml-0.1.1-DASs7VNHhWqCsnCWtz5QqF
extra-libraries:
    xml2
include-dirs: /usr/include/libxml2
includes:
    libxml/xmlIO.h libxml/xmlmemory.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
haddock-interfaces: /usr/share/doc/haskell-libxml/html/libxml.haddock
haddock-html: /usr/share/doc/haskell-libxml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libxml-0.1.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libxml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libxml
version: 0.1.1
id: libxml-0.1.1-6avle8wIbEUHYYp5CH1n6O
key: libxml-0.1.1-6avle8wIbEUHYYp5CH1n6O
license: BSD3
copyright: 2006, Lemmih
maintainer: Lemmih (lemmih@gmail.com)
synopsis: Binding to libxml2
description:
    Minimal binding to libxml2. Additional functions will be added when needed.
category: XML
author: Lemmih (lemmih@gmail.com)
exposed: True
indefinite: False
exposed-modules:
    Text.XML.LibXML Text.XML.LibXML.Internals Text.XML.LibXML.Parser
    Text.XML.LibXML.Tree Text.XML.LibXML.Types
abi: b8cc05dbc33340c433fbdce9a45802fa
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/libxml-0.1.1
hs-libraries: HSlibxml-0.1.1-6avle8wIbEUHYYp5CH1n6O
extra-libraries:
    xml2
include-dirs: /usr/include/libxml2
includes:
    libxml/xmlIO.h libxml/xmlmemory.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
haddock-interfaces: /usr/share/doc/haskell-libxml/html/libxml.haddock
haddock-html: /usr/share/doc/haskell-libxml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
